@@ -1,14 +1,20 @@
 #!/usr/bin/env perl
 # Rust macros don't allow right now to concat strings to generate method names,
-# see https://github.com/rust-lang/rust/issues/12249 for more information.
+# see https://github.com/rust-lang/rust/issues/12249 and https://github.com/rust-lang/rust/issues/29599 for more information.
 # As long as there is no way to do that in Rust this Perl script does the copy&paste&replace work for us.
 # To keep the build simple facade64.rs is still checked in.
 
 use strict;
 use warnings;
 
-open FACADE32, "<", "facade32.rs" or die $!;
-open FACADE64, ">", "facade64.rs.tmp" or die $!;
+use Cwd 'abs_path';
+use File::Basename;
+
+my $location = dirname(abs_path($0));
+print "$location\n";
+
+open FACADE32, "<", "$location/facade32.rs" or die $!;
+open FACADE64, ">", "$location/facade64.rs.tmp" or die $!;
 print FACADE64 "// Auto generated code, change facade32.rs and run facade64_create.pl\n";
 while (<FACADE32>) {
     my $line = $_;
@@ -25,8 +31,8 @@ while (<FACADE32>) {
 close FACADE32;
 close FACADE64;
 
-if (-f "facade64.rs") {
-    unlink "facade64.rs";
+if (-f "$location/facade64.rs") {
+    unlink "$location/facade64.rs";
 }
 
-rename "facade64.rs.tmp", "facade64.rs";
\ No newline at end of file
+rename "$location/facade64.rs.tmp", "$location/facade64.rs";
\ No newline at end of file
