@@ -16,12 +16,12 @@ use std::iter::Iterator;
 #[derive(PartialEq)]
 #[derive(Debug)]
 pub enum Complexity {
-	Small,
+    Small,
     Medium,
     Large
 }
 
-/// Holds parameters which specifiy how multiple cores are used
+/// Holds parameters which specify how multiple cores are used
 /// to execute an operation.
 #[derive(Debug, Copy)] 
 #[repr(C)]  
@@ -32,7 +32,6 @@ pub struct MultiCoreSettings {
     /// Indicates whether the temp arrays of a vector should already be allocated during
     /// construction
     pub early_temp_allocation: bool
-    // TODO: Specify and use options such as core/thread limits
 }
 
 impl MultiCoreSettings {
@@ -83,14 +82,14 @@ impl Chunk
     ///    The memory bus speed is limited (20GB/s in case of a typical 2015 consumer laptop in the price range of $1000) and
     ///    for operations which only require a few CPU cycles already one or two cores will process data faster than the 
     ///    memory bus is able to provide and to transport back. Using more cores then only creates heat but no performance benefit.
-	#[inline]
-	fn determine_number_of_chunks(array_length: usize, complexity: Complexity, settings: &MultiCoreSettings) -> usize
-	{
+    #[inline]
+    fn determine_number_of_chunks(array_length: usize, complexity: Complexity, settings: &MultiCoreSettings) -> usize
+    {
         let mut cores = num_cpus::get();
         if cores > settings.core_limit {
             cores = settings.core_limit;
         }
-        if complexity == Complexity::Large || cores == 1 {
+        if cores == 1 {
             cores
         }
         else if complexity == Complexity::Small  {
@@ -105,7 +104,7 @@ impl Chunk
                 }
             }
         }
-        else { // complexity == medium
+        else if complexity == Complexity::Medium {
             if array_length < 10000 {
                 1
             }
@@ -120,73 +119,80 @@ impl Chunk
                 cores
             }
         }
-	}
+        else { // complexity == Complexity::Large
+            if array_length < 30000 {
+                1
+            } else {
+                cores
+            }
+        }
+    }
     
     /// Partitions an array into the given number of chunks. It makes sure that all chunks have the same size
     /// and so it will happen that some elements at the end of the array are not part of any chunk. 
-	#[inline]
-	fn partition<T>(array: &[T], array_length: usize, step_size: usize, number_of_chunks: usize) -> Chunks<T>
-		where T : Float + Copy + Clone + Send
-	{
-		let chunk_size = Chunk::calc_chunk_size(array_length, step_size, number_of_chunks);
-		array[0 .. array_length].chunks(chunk_size)
-	}
-	
+    #[inline]
+    fn partition<T>(array: &[T], step_size: usize, number_of_chunks: usize) -> Chunks<T>
+        where T: Copy + Clone + Send + Sync
+    {
+        let chunk_size = Chunk::calc_chunk_size(array.len(), step_size, number_of_chunks);
+        array[0 .. array.len()].chunks(chunk_size)
+    }
+    
     /// Partitions an array into the given number of chunks. It makes sure that all chunks have the same size
     /// and so it will happen that some elements at the end of the array are not part of any chunk. 
-	#[inline]
-	fn partition_mut<T>(array: &mut [T], array_length: usize, step_size: usize, number_of_chunks: usize) -> ChunksMut<T>
-		where T : Copy + Clone + Send
-	{
-		let chunk_size = Chunk::calc_chunk_size(array_length, step_size, number_of_chunks);
-		array[0 .. array_length].chunks_mut(chunk_size)
-	}
-	
-	#[inline]
-	fn calc_chunk_size(array_length: usize, step_size: usize, number_of_chunks: usize) -> usize
-	{
-		let mut chunk_size = (array_length as f64/ number_of_chunks as f64).ceil() as usize;
-		let remainder = chunk_size % step_size;
-		if remainder > 0
-		{
-			chunk_size += step_size - chunk_size % step_size;
-		}
-		
-		chunk_size
-	}
-	
+    #[inline]
+    fn partition_mut<T>(array: &mut [T],  step_size: usize, number_of_chunks: usize) -> ChunksMut<T>
+        where T : Copy + Clone + Send
+    {
+        let chunk_size = Chunk::calc_chunk_size(array.len(), step_size, number_of_chunks);
+        array.chunks_mut(chunk_size)
+    }
+    
+    #[inline]
+    fn calc_chunk_size(array_length: usize, step_size: usize, number_of_chunks: usize) -> usize
+    {
+        let mut chunk_size = (array_length as f64/ number_of_chunks as f64).ceil() as usize;
+        let remainder = chunk_size % step_size;
+        if remainder > 0
+        {
+            chunk_size += step_size - chunk_size % step_size;
+        }
+        
+        chunk_size
+    }
+    
     /// This function returns the ranges which correspond to the chunks generated by `partition_in_number`. 
-	#[inline]
-	fn partition_in_ranges(array_length: usize, step_size: usize, number_of_chunks: usize) -> Vec<Range<usize>>
-	{
-		let chunk_size = Chunk::calc_chunk_size(array_length, step_size, number_of_chunks);
-		let mut ranges = Vec::with_capacity(number_of_chunks);
-		let mut sum = 0;
-		for i in 0..number_of_chunks {
-			let new_sum = if i < number_of_chunks - 1 { sum + chunk_size } else { array_length };
-			ranges.push(Range { start: sum, end: new_sum });
-			sum = new_sum;
-		} 
-		
-		ranges
-	}
-	
+    #[inline]
+    fn partition_in_ranges(array_length: usize, step_size: usize, number_of_chunks: usize) -> Vec<Range<usize>>
+    {
+        let chunk_size = Chunk::calc_chunk_size(array_length, step_size, number_of_chunks);
+        let mut ranges = Vec::with_capacity(number_of_chunks);
+        let mut sum = 0;
+        for i in 0..number_of_chunks {
+            let new_sum = if i < number_of_chunks - 1 { sum + chunk_size } else { array_length };
+            ranges.push(Range { start: sum, end: new_sum });
+            sum = new_sum;
+        } 
+        
+        ranges
+    }
+    
     /// Executes the given function on the first `array_length` elements of the given array in parallel and passes
     /// the argument to all function calls.
-	#[inline]
-	pub fn execute_partial<T,S,F>(
+    #[inline]
+    pub fn execute_partial<T,S,F>(
             complexity: Complexity, 
             settings: &MultiCoreSettings, 
-            array: &mut [T], array_length: usize, step_size: usize, 
+            array: &mut [T], step_size: usize, 
             arguments:S, ref function: F)
-		where F: Fn(&mut [T], S) + 'static + Sync, 
-			  T: RealNumber,
-			  S: Sync + Copy + Send
-	{
-		let number_of_chunks = Chunk::determine_number_of_chunks(array_length, complexity, settings);
-		if number_of_chunks > 1
-		{
-            let chunks = Chunk::partition_mut(array, array_length, step_size, number_of_chunks);
+        where F: Fn(&mut [T], S) + 'static + Sync, 
+              T: RealNumber,
+              S: Sync + Copy + Send
+    {   let array_length = array.len();
+        let number_of_chunks = Chunk::determine_number_of_chunks(array_length, complexity, settings);
+        if number_of_chunks > 1
+        {
+            let chunks = Chunk::partition_mut(array, step_size, number_of_chunks);
             crossbeam::scope(|scope| {
                 for chunk in chunks {
                     scope.spawn(move|| {
@@ -194,30 +200,103 @@ impl Chunk
                     });
                 }
             });
-		}
-		else
-		{
-			function(&mut array[0..array_length], arguments);
-		}
-	}
+        }
+        else
+        {
+            function(array, arguments);
+        }
+    }
+    
+    /// Executes the given function on the first `array_length` elements of the given list of arrays in parallel and passes
+    /// the argument to all function calls. 
+    #[inline]
+    pub fn execute_partial_multidim<T,S,F>(
+            complexity: Complexity, 
+            settings: &MultiCoreSettings, 
+            array: &mut [&mut [T]], range: Range<usize>, step_size: usize, 
+            arguments:S, ref function: F)
+        where F: Fn(&mut Vec<&mut [T]>, Range<usize>, S) + 'static + Sync, 
+              T: RealNumber,
+              S: Sync + Copy + Send
+    {
+        let dimensions = array.len();
+        let number_of_chunks = Chunk::determine_number_of_chunks(range.end - range.start, complexity, settings);
+        if number_of_chunks > 1
+        {
+            let ranges = Chunk::partition_in_ranges(range.end - range.start, step_size, number_of_chunks);
+            // As an example: If this function is called with 2 arrays,
+            // and each array has 1000 elements and is split into 4 chunks then
+            // this:
+            // let matrix = array.iter_mut().map(|a| {
+            //    Chunk::partition_mut(a, array_length, step_size, number_of_chunks)
+            //}).collect();
+            // would give us a layout like this:
+            // Vector with 2 elements * 4 chunks * each chunk with 250 elements (mutable)
+            //
+            // But what we want to have is:
+            // 4 chunks * a vector of 2 elements * 250 elements in each vector (mutable)
+            //
+            // We achieve this by a) flatten the structure (flat_map) so that we get:
+            // array1 chunk1
+            // array1 chunk2
+            // array1 chunk3
+            // array1 chunk4
+            // array2 chunk1
+            // array2 chunk2
+            // array2 chunk3
+            // array2 chunk4
+            //
+            // and b) creating a nested vector structure so that we can push
+            // the elements on it in the correct order
+            let mut flat_layout: Vec<&mut [T]> = array.iter_mut().flat_map(|a| {
+                Chunk::partition_mut(&mut a[range.start .. range.end], step_size, number_of_chunks)
+            }).collect();
+            
+            let mut reorganized = Vec::with_capacity(number_of_chunks);
+            for _ in 0..number_of_chunks {
+                reorganized.push(Vec::with_capacity(dimensions));
+            }
+            let mut i = flat_layout.len();
+            while i > 0 {
+                let elem = flat_layout.pop().unwrap();
+                reorganized[i % number_of_chunks].push(elem);
+                i-=1;
+            }
+            
+            crossbeam::scope(|scope| {
+                for chunk in reorganized.iter_mut().zip(ranges) {
+                    scope.spawn(move|| {
+                        function(chunk.0, chunk.1, arguments);
+                    });
+                }
+            });
+        }
+        else
+        {
+          let mut shortened: Vec<&mut [T]> = 
+            array.iter_mut().map(|a|&mut a[range.start..range.end]).collect();
+          function(&mut shortened, range, arguments);
+        }
+    }
     
     /// Executes the given function on the all elements of the array and also tells the function on which range/chunk
     /// it operates on.
-	#[inline]
-	pub fn execute_with_range<T,S,F>(
+    #[inline]
+    pub fn execute_with_range<T,S,F>(
             complexity: Complexity, 
             settings: &MultiCoreSettings, 
-            array: &mut [T], array_length: usize, step_size: usize, 
+            array: &mut [T], step_size: usize, 
             arguments: S, ref function: F)
-		where F: Fn(&mut [T], Range<usize>, S) + 'static + Sync,
-			  T : Copy + Clone + Send + Sync,
-			  S: Sync + Copy + Send
-	{
-		let number_of_chunks = Chunk::determine_number_of_chunks(array_length, complexity, settings);
-		if number_of_chunks > 1
-		{
-			let chunks = Chunk::partition_mut(array, array_length, step_size, number_of_chunks);
-			let ranges = Chunk::partition_in_ranges(array_length, step_size, chunks.len());
+        where F: Fn(&mut [T], Range<usize>, S) + 'static + Sync,
+              T : Copy + Clone + Send + Sync,
+              S: Sync + Copy + Send
+    {
+        let array_length = array.len();
+        let number_of_chunks = Chunk::determine_number_of_chunks(array_length, complexity, settings);
+        if number_of_chunks > 1
+        {
+            let chunks = Chunk::partition_mut(array, step_size, number_of_chunks);
+            let ranges = Chunk::partition_in_ranges(array_length, step_size, chunks.len());
             crossbeam::scope(|scope| {
                 for chunk in chunks.zip(ranges) {
                     scope.spawn(move|| {
@@ -225,35 +304,76 @@ impl Chunk
                     });
                 }
             });
-		}
-		else
-		{
-			function(&mut array[0..array_length], Range { start: 0, end: array_length }, arguments);
-		}
-	}
+        }
+        else
+        {
+            function(array, Range { start: 0, end: array_length }, arguments);
+        }
+    }
+    
+    /// Executes the given function on an unspecified number and size of chunks on the array and
+    /// returns the result of each chunk.
+    #[inline]
+    pub fn map_on_array_chunks<T,S,F, R>(
+            complexity: Complexity, 
+            settings: &MultiCoreSettings, 
+            array: &[T], step_size: usize, 
+            arguments: S, ref function: F) -> Vec<R>
+        where F: Fn(&[T], Range<usize>, S) -> R + 'static + Sync,
+              T : Copy + Clone + Send + Sync,
+              S: Sync + Copy + Send,
+              R: Send
+    {
+        let array_len = array.len();
+        let number_of_chunks = Chunk::determine_number_of_chunks(array.len(), complexity, settings);
+        if number_of_chunks > 1
+        {
+            let chunks = Chunk::partition(array, step_size, number_of_chunks);
+            let ranges = Chunk::partition_in_ranges(array_len, step_size, chunks.len());
+            let result = Vec::with_capacity(chunks.len());
+            let stack_array = Arc::new(Mutex::new(result));
+            crossbeam::scope(|scope| {
+                for chunk in chunks.zip(ranges) {
+                    let stack_array = stack_array.clone();
+                    scope.spawn(move|| {
+                        let r = function(chunk.0, chunk.1, arguments);
+                        stack_array.lock().unwrap().push(r);
+                    });
+                }
+            });
+            let mut guard = stack_array.lock().unwrap();
+            mem::replace(&mut guard, Vec::new())
+        }
+        else
+        {
+            let result = function(array, Range { start: 0, end: array_len }, arguments);
+            vec![result]
+        }
+    }
     
     /// Executes the given function on the all elements of the array and also tells the function on which range/chunk
     /// it operates on.
     ///
     /// This function will chunk the array into an even number and pass every
     /// call to `function` two chunks. The two chunks will always be symmetric 
-    /// around 0. This allos `function` to make use of symmetry properties of the
+    /// around 0. This allows `function` to make use of symmetry properties of the
     /// underlying data or the argument.
-	#[inline]
-	pub fn execute_sym_pairs_with_range<T,S,F>(
+    #[inline]
+    pub fn execute_sym_pairs_with_range<T,S,F>(
             complexity: Complexity, 
             settings: &MultiCoreSettings, 
-            array: &mut [T], array_length: usize, step_size: usize, 
+            array: &mut [T], step_size: usize, 
             arguments: S, ref function: F)
-		where F: Fn(&mut &mut [T], &Range<usize>, &mut &mut [T], &Range<usize>, S) + 'static + Sync,
-			  T: Copy + Clone + Send + Sync,
-			  S: Sync + Copy + Send
-	{
-		let number_of_chunks = 2 * Chunk::determine_number_of_chunks(array_length, complexity, settings);
-		if number_of_chunks > 2
-		{
-			let chunks = Chunk::partition_mut(array, array_length, step_size, number_of_chunks);
-			let ranges = Chunk::partition_in_ranges(array_length, step_size, chunks.len());
+        where F: Fn(&mut &mut [T], &Range<usize>, &mut &mut [T], &Range<usize>, S) + 'static + Sync,
+              T: Copy + Clone + Send + Sync,
+              S: Sync + Copy + Send
+    {
+        let array_length = array.len();
+        let number_of_chunks = 2 * Chunk::determine_number_of_chunks(array_length, complexity, settings);
+        if number_of_chunks > 2
+        {
+            let chunks = Chunk::partition_mut(array, step_size, number_of_chunks);
+            let ranges = Chunk::partition_in_ranges(array_length, step_size, chunks.len());
             let mut i = 0;
             let (mut chunks1, mut chunks2): (Vec<_>, Vec<_>) = 
                 chunks.partition(|_c| { i += 1; i <= number_of_chunks / 2 });
@@ -272,40 +392,42 @@ impl Chunk
                     });
                 }
             });
-		}
-		else
-		{
-            let mut chunks = Chunk::partition_mut(array, array_length, step_size, number_of_chunks);
+        }
+        else
+        {
+            let mut chunks = Chunk::partition_mut(array, step_size, number_of_chunks);
             let mut chunks1 = chunks.next().unwrap();
             let len1 = chunks1.len();
             let mut chunks2 = chunks.next().unwrap();
-			function(
+            function(
                 &mut chunks1, 
                 &Range { start: 0, end: len1 }, 
                 &mut chunks2, 
                 &Range { start: len1, end: array_length }, 
                 arguments);
-		}
-	}
+        }
+    }
     
     /// Executes the given function on the all elements of the array in parallel. A result is
     /// returned for each chunk.
-	#[inline]
-	pub fn get_a_fold_b<F, T, R>(
+    #[inline]
+    pub fn get_a_fold_b<F, T, R>(
             complexity: Complexity, 
             settings: &MultiCoreSettings, 
-            a: &[T], a_len: usize, a_step: usize, 
-            b: &[T], b_len: usize, b_step: usize, 
+            a: &[T], a_step: usize, 
+            b: &[T], b_step: usize, 
             ref function: F) -> Vec<R>
-		where F: Fn(&[T], Range<usize>, &[T]) -> R + 'static + Sync,
-			  T: Float + Copy + Clone + Send + Sync,
+        where F: Fn(&[T], Range<usize>, &[T]) -> R + 'static + Sync,
+              T: Float + Copy + Clone + Send + Sync,
               R: Send
-	{
-		let number_of_chunks = Chunk::determine_number_of_chunks(a_len, complexity, settings);
-		if number_of_chunks > 1
-		{
-			let chunks = Chunk::partition(b, b_len, b_step, number_of_chunks);
-			let ranges = Chunk::partition_in_ranges(a_len, a_step, chunks.len());
+    {
+        let a_len = a.len();
+        let b_len = b.len();
+        let number_of_chunks = Chunk::determine_number_of_chunks(a_len, complexity, settings);
+        if number_of_chunks > 1
+        {
+            let chunks = Chunk::partition(b, b_step, number_of_chunks);
+            let ranges = Chunk::partition_in_ranges(a_len, a_step, chunks.len());
             let result = Vec::with_capacity(chunks.len());
             let stack_array = Arc::new(Mutex::new(result));
             crossbeam::scope(|scope| {
@@ -319,31 +441,32 @@ impl Chunk
             });
             let mut guard = stack_array.lock().unwrap();
             mem::replace(&mut guard, Vec::new())
-		}
-		else
-		{
-			let result = function(a, Range { start: 0, end: a_len }, &b[0..b_len]);
+        }
+        else
+        {
+            let result = function(a, Range { start: 0, end: a_len }, &b[0..b_len]);
             vec![result]
-		}
-	}
+        }
+    }
     
     /// Executes the given function on the all elements of the array in parallel. A result is
     /// returned for each chunk.
-	#[inline]
-	pub fn get_chunked_results<F, S, T, R>(
+    #[inline]
+    pub fn get_chunked_results<F, S, T, R>(
             complexity: Complexity, 
             settings: &MultiCoreSettings, 
-            a: &[T], a_len: usize, a_step: usize, 
+            a: &[T], a_step: usize, 
             arguments:S, ref function: F) -> Vec<R>
-		where F: Fn(&[T], Range<usize>, S) -> R + 'static + Sync,
-			  T: Float + Copy + Clone + Send + Sync,
+        where F: Fn(&[T], Range<usize>, S) -> R + 'static + Sync,
+              T: Float + Copy + Clone + Send + Sync,
               R: Send,
               S: Sync + Copy + Send
-	{
-		let number_of_chunks = Chunk::determine_number_of_chunks(a_len, complexity, settings);
-		if number_of_chunks > 1
-		{
-			let chunks = Chunk::partition(a, a_len, a_step, number_of_chunks);
+    {
+        let a_len = a.len();
+        let number_of_chunks = Chunk::determine_number_of_chunks(a_len, complexity, settings);
+        if number_of_chunks > 1
+        {
+            let chunks = Chunk::partition(a, a_step, number_of_chunks);
             let ranges = Chunk::partition_in_ranges(a_len, a_step, chunks.len());
             let result = Vec::with_capacity(chunks.len());
             let stack_array = Arc::new(Mutex::new(result));
@@ -358,32 +481,33 @@ impl Chunk
             });
             let mut guard = stack_array.lock().unwrap();
             mem::replace(&mut guard, Vec::new())
-		}
-		else
-		{
-			let result = function(&a[0..a_len], Range { start: 0, end: a_len }, arguments);
+        }
+        else
+        {
+            let result = function(&a[0..a_len], Range { start: 0, end: a_len }, arguments);
             vec![result]
-		}
-	}
+        }
+    }
     
     /// Executes the given function on the all elements of the array in parallel and passes
     /// the argument to all function calls.. Results are intended to be stored in the target array.
-	#[inline]
-	pub fn from_src_to_dest<T,S,F>(
+    #[inline]
+    pub fn from_src_to_dest<T,S,F>(
             complexity: Complexity, 
             settings: &MultiCoreSettings, 
-            original: &[T], original_length: usize, original_step: usize, 
-            target: &mut [T], target_length: usize, target_step: usize, 
+            original: &[T], original_step: usize, 
+            target: &mut [T], target_step: usize, 
             arguments: S, ref function: F)
-		where F: Fn(&[T], Range<usize>, &mut [T], S) + 'static + Sync,
-			  T: Float + Copy + Clone + Send + Sync,
-			  S: Sync + Copy + Send
-	{
-		let number_of_chunks = Chunk::determine_number_of_chunks(original_length, complexity, settings);
-		if number_of_chunks > 1
-		{
-			let chunks = Chunk::partition_mut(target, target_length, target_step, number_of_chunks);
-			let ranges = Chunk::partition_in_ranges(original_length, original_step, chunks.len());
+        where F: Fn(&[T], Range<usize>, &mut [T], S) + 'static + Sync,
+              T: Float + Copy + Clone + Send + Sync,
+              S: Sync + Copy + Send
+    {
+        let original_length = original.len();
+        let number_of_chunks = Chunk::determine_number_of_chunks(original_length, complexity, settings);
+        if number_of_chunks > 1
+        {
+            let chunks = Chunk::partition_mut(target, target_step, number_of_chunks);
+            let ranges = Chunk::partition_in_ranges(original_length, original_step, chunks.len());
             
             crossbeam::scope(|scope| {
                 for chunk in chunks.zip(ranges) {
@@ -392,52 +516,52 @@ impl Chunk
                     });
                 }
             });
-		}
-		else
-		{
-			function(original, Range { start: 0, end: original_length }, &mut target[0..target_length], arguments);
-		}
-	}
+        }
+        else
+        {
+            function(original, Range { start: 0, end: original_length }, target, arguments);
+        }
+    }
 }
 
 #[cfg(test)]
 mod tests {
-	use super::*;
-	use std::ops::Range;
-	
-	#[test]
-	fn partition_array()
-	{
-		let mut array = [0.0; 256];
-		let chunks = Chunk::partition_mut(&mut array, 256, 4, 2);
-		assert_eq!(chunks.len(), 2);
-		for chunk in chunks
-		{
-			assert_eq!(chunk.len(), 128);
-		}
-	}
-	
-	#[test]
-	fn partition_array_8_cores()
-	{
-		let mut array = [0.0; 1023];
-		let chunks = Chunk::partition_mut(&mut array, 1023, 4, 8);
-		assert_eq!(chunks.len(), 8);
-		let mut i = 0;
-		for chunk in chunks
-		{
-			let expected = if i >= 7 { 127 } else { 128 };
-			assert_eq!(chunk.len(), expected);
-			i += 1;
-		}
-	}
-	
-	#[test]
-	fn partitionin_ranges()
-	{
-		let ranges = Chunk::partition_in_ranges(1023, 4, 2);
-		assert_eq!(ranges.len(), 2);
-		assert_eq!(ranges[0], Range { start: 0, end: 512 });
-		assert_eq!(ranges[1], Range { start: 512, end: 1023 });
-	}
+    use super::*;
+    use std::ops::Range;
+    
+    #[test]
+    fn partition_array()
+    {
+        let mut array = [0.0; 256];
+        let chunks = Chunk::partition_mut(&mut array, 4, 2);
+        assert_eq!(chunks.len(), 2);
+        for chunk in chunks
+        {
+            assert_eq!(chunk.len(), 128);
+        }
+    }
+    
+    #[test]
+    fn partition_array_8_cores()
+    {
+        let mut array = [0.0; 1023];
+        let chunks = Chunk::partition_mut(&mut array, 4, 8);
+        assert_eq!(chunks.len(), 8);
+        let mut i = 0;
+        for chunk in chunks
+        {
+            let expected = if i >= 7 { 127 } else { 128 };
+            assert_eq!(chunk.len(), expected);
+            i += 1;
+        }
+    }
+    
+    #[test]
+    fn partitionin_ranges()
+    {
+        let ranges = Chunk::partition_in_ranges(1023, 4, 2);
+        assert_eq!(ranges.len(), 2);
+        assert_eq!(ranges[0], Range { start: 0, end: 512 });
+        assert_eq!(ranges[1], Range { start: 512, end: 1023 });
+    }
 }
