@@ -149,11 +149,9 @@ impl Simd<f32> for f32x4
     #[inline]
     fn store_half_unchecked(self, target: &mut [f32], index: usize)
     {
-        let mut temp = [0.0; 4];
-        self.store(&mut temp, 0);
         unsafe {
-            *target.get_unchecked_mut(index) = temp[0];
-            *target.get_unchecked_mut(index + 1) = temp[1];
+            *target.get_unchecked_mut(index) = self.extract(0);
+            *target.get_unchecked_mut(index + 1) = self.extract(1);
         }
     }
     
@@ -304,4 +302,4 @@ impl Simd<f64> for f64x2
     fn sum_complex(&self) -> Complex<f64> {
         Complex::<f64>::new(self.extract(0), self.extract(1))
     }
-} 
\ No newline at end of file
+} 
