@@ -51,12 +51,12 @@ pub trait VectorConvolution<T> : DataVector<T>
 /// Provides a frequency response multiplication operation for data vectors.
 pub trait FrequencyMultiplication<T, C> : DataVector<T> 
     where T : RealNumber {
-    /// Mutiplies `self` with the frequency response function `frequency_response`.
+    /// Multiplies `self` with the frequency response function `frequency_response`.
     /// 
     /// In order to multiply a vector with another vector in frequency response use `multiply_vector`.
     /// # Assumptions
     /// The operation assumes that the vector contains a full spectrum centered at 0 Hz. If half a spectrum
-    /// or a fft shifted spectrum is provided the operation will come back with invalid results.
+    /// or a FFT shifted spectrum is provided the operation will come back with invalid results.
     /// # Failures
     /// VecResult may report the following `ErrorReason` members:
     /// 
@@ -360,12 +360,7 @@ macro_rules! add_conv_impl{
                         let dest = convert_mut(&mut temp[0..len]);
                         let other_iter = &other[other_start .. other_end];
 
-                        let shifted_copies = Self::create_shifted_copies(vector);
-                        let mut shifts = Vec::with_capacity(shifted_copies.len());
-                        for shift in 0..shifted_copies.len() {
-                            let simd = $reg::array_to_regs(&shifted_copies[shift]);
-                            shifts.push(simd);
-                        }
+                        let shifts = Self::create_shifted_copies(vector);
 
                         let scalar_len = conv_len + $reg::len(); // + $reg::len() due to rounding of odd numbers
                         let conv_len = conv_len as isize;
@@ -375,14 +370,14 @@ macro_rules! add_conv_impl{
                             i += 1;
                         }
 
-                        let len_rounded = (len / $reg::len()) * $reg::len(); // The exact value is of no importance here
-                        let simd = $reg::array_to_regs(&self.data[0..len_rounded]);
+                        let (scalar_left, _, vectorization_length) = $reg::calc_data_alignment_reqs(&self.data[0..len]);
+                        let simd = $reg::array_to_regs(&self.data[scalar_left..vectorization_length]);
                         for num in &mut dest[scalar_len .. points - scalar_len] {
                             let end = (i + conv_len) as usize;
                             let shift = end % shifts.len();
                             let end = (end + shifts.len() - 1) / shifts.len();
                             let mut sum = $reg::splat(0.0);
-                            let shifted = shifts[shift];
+                            let shifted = &shifts[shift];
                             let simd_iter = simd[end - shifted.len() .. end].iter(); 
                             let iteration = 
                                 simd_iter
@@ -601,7 +596,7 @@ mod tests {
     }
     
     #[test]
-	fn convolve_complex_freq_and_freq32() {
+    fn convolve_complex_freq_and_freq32() {
         let vector = ComplexFreqVector32::from_constant(Complex32::new(1.0, 1.0), 5);
         let rc: RaisedCosineFunction<f32> = RaisedCosineFunction::new(1.0);
         let result = vector.multiply_frequency_response(&rc as &RealFrequencyResponse<f32>, 2.0).unwrap();
@@ -611,7 +606,7 @@ mod tests {
     }
     
     #[test]
-	fn convolve_complex_freq_and_freq_even32() {
+    fn convolve_complex_freq_and_freq_even32() {
         let vector = ComplexFreqVector32::from_constant(Complex32::new(1.0, 1.0), 6);
         let rc: RaisedCosineFunction<f32> = RaisedCosineFunction::new(1.0);
         let result = vector.multiply_frequency_response(&rc as &RealFrequencyResponse<f32>, 2.0).unwrap();
@@ -621,7 +616,7 @@ mod tests {
     }
     
     #[test]
-	fn convolve_real_time_and_time32() {
+    fn convolve_real_time_and_time32() {
         let vector = RealTimeVector32::from_array(&[0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0]);
         let rc: RaisedCosineFunction<f32> = RaisedCosineFunction::new(0.35);
         let result = vector.convolve(&rc as &RealImpulseResponse<f32>, 0.2, 5).unwrap();
@@ -632,7 +627,7 @@ mod tests {
     }
     
     #[test]
-	fn convolve_complex_time_and_time32() {
+    fn convolve_complex_time_and_time32() {
         let len = 11;
         let mut time = ComplexTimeVector32::from_constant(Complex32::new(0.0, 0.0), len);
         time[len] = 1.0;
@@ -664,7 +659,7 @@ mod tests {
     }
     
     #[test]
-	fn invalid_length_parameter() {
+    fn invalid_length_parameter() {
         let len = 20;
         let time = ComplexTimeVector32::from_constant(Complex32::new(0.0, 0.0), len);
         let sinc: SincFunction<f32> = SincFunction::new();
@@ -673,7 +668,7 @@ mod tests {
     }
     
     #[test]
-	fn convolve_complex_vectors32() {
+    fn convolve_complex_vectors32() {
         const LEN: usize = 11;
         let mut time = ComplexTimeVector32::from_constant(Complex32::new(0.0, 0.0), LEN);
         time[LEN] = 1.0;
