@@ -228,12 +228,9 @@ macro_rules! add_real_impl {
                         &array[0..data_length], 1, (),
                         |array, range, _arg| {
                             let mut stats = Statistics::empty();
-                            let mut i = 0;
                             let mut j = range.start;
-                            while i < array.len()
-                            { 
-                                stats.add(array[i], j);
-                                i += 1;
+                            for num in array { 
+                                stats.add(*num, j);
                                 j += 1;
                             }
                             stats
@@ -254,12 +251,10 @@ macro_rules! add_real_impl {
                         &array[0..data_length], 1, len,
                         |array, range, len| {
                             let mut results = Statistics::empty_vec(len);
-                            let mut i = 0;
                             let mut j = range.start;
-                            while i < array.len() {
-                                let stats = &mut results[i % len];
-                                stats.add(array[i], j / len);
-                                i += 1;
+                            for num in array {
+                                let stats = &mut results[j % len];
+                                stats.add(*num, j / len);
                                 j += 1;
                             }
                             
@@ -268,6 +263,76 @@ macro_rules! add_real_impl {
                     
                     Statistics::merge_cols(&chunks)
                 }
+                
+                fn real_sum(&self) -> $data_type {
+                    let data_length = self.len();
+                    let (scalar_left, scalar_right, vectorization_length) = $reg::calc_data_alignment_reqs(&self.data[0..data_length]);
+                    let array = &self.data;
+                    let mut sum = 
+                        if vectorization_length > 0 {
+                            let chunks = Chunk::get_chunked_results(
+                                Complexity::Small, &self.multicore_settings,
+                                &array[scalar_left..vectorization_length], $reg::len(), (), 
+                                move |array, _, _| {
+                                let array = $reg::array_to_regs(array);
+                                let mut sum = $reg::splat(0.0);
+                                for reg in array {
+                                    sum = sum + *reg;
+                                }
+                                sum
+                            });
+                            chunks.iter()
+                                .map(|v|v.sum_real())
+                                .sum()
+                        } 
+                        else {
+                            0.0
+                        };
+                    for num in &array[0..scalar_left]
+                    {
+                        sum = sum + *num;
+                    }
+                    for num in &array[scalar_right..data_length]
+                    {
+                        sum = sum + *num;
+                    }
+                    sum
+                }
+                
+                fn real_sum_sq(&self) -> $data_type {
+                    let data_length = self.len();
+                    let (scalar_left, scalar_right, vectorization_length) = $reg::calc_data_alignment_reqs(&self.data[0..data_length]);
+                    let array = &self.data;
+                    let mut sum = 
+                        if vectorization_length > 0 {
+                            let chunks = Chunk::get_chunked_results(
+                                Complexity::Small, &self.multicore_settings,
+                                &array[scalar_left..vectorization_length], $reg::len(), (), 
+                                move |array, _, _| {
+                                let array = $reg::array_to_regs(array);
+                                let mut sum = $reg::splat(0.0);
+                                for reg in array {
+                                    sum = sum + *reg * *reg;
+                                }
+                                sum
+                            });
+                            chunks.iter()
+                                .map(|v|v.sum_real())
+                                .sum()
+                        } 
+                        else {
+                            0.0
+                        };
+                    for num in &array[0..scalar_left]
+                    {
+                        sum = sum + *num * *num;
+                    }
+                    for num in &array[scalar_right..data_length]
+                    {
+                        sum = sum + *num * *num;
+                    }
+                    sum
+                }
             }
             
             impl ScaleOps<$data_type> for GenericDataVector<$data_type> {
@@ -296,6 +361,14 @@ macro_rules! add_real_impl {
                 fn statistics_splitted(&self, len: usize) -> Vec<Statistics<$data_type>> {
                     self.real_statistics_splitted(len)
                 }
+                
+                fn sum(&self) -> $data_type {
+                    self.real_sum()
+                }
+                
+                fn sum_sq(&self) -> $data_type {
+                    self.real_sum_sq()
+                }
             }
             
             impl VectorIter<$data_type> for GenericDataVector<$data_type> {
